from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Texas = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'LM3S6911-EQC50', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM3S6911-EQC50'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'MCU ARM M3 Stellaris PHY ETH NRND', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm3s6911.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nLM3S6911-EQC50\n\nMCU ARM M3 Stellaris PHY ETH NRND', 'pins':[
            Pin(num='1',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD7/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2/U1RX',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3/U1TX',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD25',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTALPPHY',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='XTALNPHY',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='PG1/U2TX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG0/U2RX',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE6/C1O',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='CCP4/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='CCP3/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='C1+/C0O/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='CCP5/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VCCPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='RXIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VDD25',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='RXIP',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='ERBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='GNDPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='TXOP',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='TXON',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='~{HIB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='52',name='XOSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='XOSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='MDIO',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='PF3/LED0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF2/LED1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD25',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='CMOD0',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='CCP2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='LDO',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='I2C0SCL/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='I2C0SDA/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PE0/SSI1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE1/SSI1FSS',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE2/SSI1RX',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE3/SSI1TX',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='CMOD1',func=pin_types.INPUT,unit=1),
            Pin(num='77',name='SWO/TDO/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='TDI/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='SWDIO/TMS/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='SWCLK/TCK/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='82',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VCCPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='VCCPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='GNDPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='86',name='GNDPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='VDD25',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='~{TRST}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='C0+/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='C1-/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='C0-/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='99',name='PD6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP432E401Y', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP432E401Y'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'ARM Cortex-M4F MSP432 MSP432E4 MSP432E401', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp432e401y.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nMSP432E401Y\n\nARM Cortex-M4F MSP432 MSP432E4 MSP432E401', 'pins':[
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='PC0/TCK/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='102',name='PQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PP2',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PP3',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PP4',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PP5',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PN0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PN1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PN2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PN3',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PN4',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PN5',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PP0',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PP1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='EN0RXIN',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='EN0RXIP',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='EN0TXON',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='EN0TXOP',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='RBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='~{HIB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='66',name='XOSC0',func=pin_types.INPUT,unit=1),
            Pin(num='67',name='XOSC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='68',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='71',name='PM7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PM6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PM5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PM4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PM3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PM2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PM1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PM0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='OSC0',func=pin_types.INPUT,unit=1),
            Pin(num='89',name='OSC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VREFA+',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC3/TDO/SWO',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC2/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC1/TMS/SWDIO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TM4C1230C3PM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TM4C1230C3PM'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Tiva Cortex M4 MCU', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1230c3pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nTM4C1230C3PM\n\nARM Tiva Cortex M4 MCU', 'pins':[
            Pin(num='1',name='I2C5SCL/SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/NMI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PG5/WT0CCP1/U2TX/I2C1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG4/WT0CCP0/U2RX/I2C1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG3/T5CCP1/I2C4SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG2/T5CCP0/I2C4SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1/T4CCP1/I2C3SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PG0/T4CCP0/I2C3SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='I2C5SDA/SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TM4C1231C3PM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TM4C1231C3PM'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Tiva Cortex M4 MCU', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1231c3pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nTM4C1231C3PM\n\nARM Tiva Cortex M4 MCU', 'pins':[
            Pin(num='1',name='SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/MNI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{HIB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='34',name='XOSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GNDX',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='XOSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMS320LF2406', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMS320LF2406'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nTMS320LF2406\n\n', 'pins':[
            Pin(num='77',name='ADCIN1',func=pin_types.INPUT),
            Pin(num='0',name='BOOT_EN*/XF',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='TRST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PLLVCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='TDIRA/IOPB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='T1PWM/T1CMP/IOPB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='T2PWM/T2CMP/IOPB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IOPC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='XINT2/ADSOC/IOPD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='XINT1/IOPA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SCITxD/IOPA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SCIRxD/IOPA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TDIRB/IOPF4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='SPISIMO/IOPC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SPISOMI/IOPC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SPISTE*/IOPC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SPICLK/IOPC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TMS2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='TCLKINA/IOPB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PWM12/IOPE6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PWM6/IOPB3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GNDO',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GNDO',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDDO',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PWM5/IOPB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PWM11/IOPE5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PWM4/IOPB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PWM3/IOPB0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PWM2/IOPA7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PWM10/IOPE4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PWM1/IOPA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDDO',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='VprogFLASH',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='PWM9/IOPE3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PWM8/IOPE2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PWM7/IOPE1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='GNDO',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='CAP6/IOPF1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='CANRX/IOPC7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='T4PWM/T4CMP/IOPF3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='CANTX/IOPC6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='CLKOUT/IOPE0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='CAP3/QEP3/IOPA5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='GNDO',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='VDDO',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='CAP2/QEP2/IOPA4',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='CAP5/QEP4/IOPF0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='CAP1/QEP1/IOPA3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PDPINTA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='CAP4/QEP3/IOPE7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='EMU0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='EMU1/OFF*',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='GNDO',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VDDO',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='ADCIN15',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='ADCIN7',func=pin_types.INPUT,unit=1),
            Pin(num='67',name='ADCIN6',func=pin_types.INPUT,unit=1),
            Pin(num='68',name='ADCIN14',func=pin_types.INPUT,unit=1),
            Pin(num='69',name='ADCIN5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='T3PWM/T3CMP/IOPF2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='ADCIN13',func=pin_types.INPUT,unit=1),
            Pin(num='72',name='ADCIN3',func=pin_types.INPUT,unit=1),
            Pin(num='72',name='ADCIN4',func=pin_types.INPUT,unit=1),
            Pin(num='73',name='ADCIN12',func=pin_types.INPUT,unit=1),
            Pin(num='74',name='ADCIN2',func=pin_types.INPUT,unit=1),
            Pin(num='75',name='ADCIN11',func=pin_types.INPUT,unit=1),
            Pin(num='76',name='ADCIN10',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='ADCIN9',func=pin_types.INPUT,unit=1),
            Pin(num='79',name='ADCIN0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PLLF2',func=pin_types.INPUT,unit=1),
            Pin(num='80',name='ADCIN8',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='VREFLO',func=pin_types.INPUT,unit=1),
            Pin(num='82',name='VREFHI',func=pin_types.INPUT,unit=1),
            Pin(num='83',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='BIO*/IOPC1',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='XTAL1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='88',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='89',name='TCKINB/IOPF5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PLLF',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='IOPF6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='94',name='TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PDPINTB',func=pin_types.INPUT,unit=1),
            Pin(num='96',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='97',name='GNDO',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='VDDO',func=pin_types.PWRIN,unit=1),
            Pin(num='99',name='TDO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMS470R1B768', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMS470R1B768'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'ARM 7TDM uC TMS470', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tms470r1b768.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nTMS470R1B768\n\nARM 7TDM uC TMS470', 'pins':[
            Pin(num='1',name='~{SPI1ENA}',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SPI4CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='ADIN[7]',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='ADIN[6]',func=pin_types.PASSIVE,unit=1),
            Pin(num='102',name='ADIN[5]',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='ADIN[15]',func=pin_types.PASSIVE,unit=1),
            Pin(num='104',name='ADIN[4]',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='ADIN[3]',func=pin_types.PASSIVE,unit=1),
            Pin(num='106',name='ADIN[2]',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='ADIN[1]',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='ADIN[0]',func=pin_types.PASSIVE,unit=1),
            Pin(num='109',name='ADIN[11]',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='110',name='ADIN[14]',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='ADIN[10]',func=pin_types.PASSIVE,unit=1),
            Pin(num='112',name='ADIN[13]',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='ADIN[9]',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='ADIN[12]',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='ADIN[8]',func=pin_types.PASSIVE,unit=1),
            Pin(num='116',name='ADRefHi',func=pin_types.PASSIVE,unit=1),
            Pin(num='117',name='ADRefLo',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VccAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VssAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OSCOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='TMS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='TMS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='122',name='GIOC[0]',func=pin_types.PASSIVE,unit=1),
            Pin(num='123',name='HET[23]',func=pin_types.PASSIVE,unit=1),
            Pin(num='124',name='HET[25]',func=pin_types.PASSIVE,unit=1),
            Pin(num='125',name='HET[26]',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='HET[27]',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='Vss',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='Vcc',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='HET[0]',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OSCIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='130',name='HET[1]',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='Vss',func=pin_types.PASSIVE,unit=1),
            Pin(num='132',name='Vcc',func=pin_types.PASSIVE,unit=1),
            Pin(num='133',name='FLTP2',func=pin_types.PASSIVE,unit=1),
            Pin(num='134',name='FLTP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VccP',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='Vss',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='HET[2]',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='HET[3]',func=pin_types.PASSIVE,unit=1),
            Pin(num='139',name='HET[4]',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Vcc',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='HET[5]',func=pin_types.PASSIVE,unit=1),
            Pin(num='141',name='HET[6]',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='HET[7]',func=pin_types.PASSIVE,unit=1),
            Pin(num='143',name='GIOC[1]',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='GIOC[2]',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VssIO',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VccIO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GIOD[3]',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GIOD[2]',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~{SPI1SCS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='GIOD[1]',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GIOD[0]',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='HET[17]',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='HET[16]',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='HET[15]',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='HET[14]',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='HET[13]',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='HET[12]',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='HET[11]',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='HET[10]',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SPI1SIMO',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Vss',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Vcc',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='~{PORST}',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='GIOA[7]/INT7',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='GIOA[6]/INT6',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GIOA[5]/INT5',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GIOA[4]/INT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='TEST',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GIOA[0]/INT0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SPI1SOMI',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='GIOA[1]/INT1/ECLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GIOA[2]/INT2',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='GIOA[3]/INT3',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='SCI2RX',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='SCI2TX',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='SCI2CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='~{SPI5SCS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='HET[28]',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='HET[29]',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='HET[30]',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='SPI1CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='HET[31]',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='HET[24]',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VssIO',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='VccIO',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='Vcc',func=pin_types.UNSPEC,unit=1),
            Pin(num='56',name='CAN2HTX',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='CAN2HRX',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='SPI5SIMO',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='SPI5SOMI',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{SPI4ENA}',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='SPI5CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='~{SPI5ENA}',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SPI2CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='SPI2SIMO',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='SPI2SOMI',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='~{SPI2ENA}',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='~{SPI2SCS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='HET[22]',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='HET[21]',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='HET[20]',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~{SPI4SCS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='HET[19]',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='HET[18]',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='AWD',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='PLLDIS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='TDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='TDO5',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='TCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='CAN3HRX',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='CAN3HTX',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='HET[8]',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SPI4SIMO',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='HET[9]',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='VssIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VccIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='CLKOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GIOB[7]',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='Vss',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='Vcc',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='CAN1HRX',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='CAN1HTX',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='SCI1CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='SPI4SOMI',func=pin_types.PASSIVE,unit=1),
            Pin(num='90',name='SCI1TX',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='SCI1RX',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='Vss',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='Vcc',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='SPI3CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='SPI3SOMI',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='SPI3SIMO',func=pin_types.PASSIVE,unit=1),
            Pin(num='97',name='~{SPI3SCS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='98',name='~{SPI3ENA}',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='ADEVT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM3S6911-IQC50', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM3S6911-IQC50'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'MCU ARM M3 Stellaris PHY ETH NRND', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm3s6911.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nLM3S6911-IQC50\n\nMCU ARM M3 Stellaris PHY ETH NRND', 'pins':[
            Pin(num='1',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD7/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2/U1RX',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3/U1TX',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD25',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTALPPHY',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='XTALNPHY',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='PG1/U2TX',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG0/U2RX',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE6/C1O',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='CCP4/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='CCP3/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='C1+/C0O/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='CCP5/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VCCPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='RXIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VDD25',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='RXIP',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='ERBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='GNDPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='TXOP',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='TXON',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='~{HIB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='52',name='XOSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='XOSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='MDIO',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='PF3/LED0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF2/LED1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD25',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='CMOD0',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='CCP2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='LDO',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='I2C0SCL/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='I2C0SDA/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PE0/SSI1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE1/SSI1FSS',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE2/SSI1RX',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE3/SSI1TX',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='CMOD1',func=pin_types.INPUT,unit=1),
            Pin(num='77',name='SWO/TDO/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='TDI/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='SWDIO/TMS/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='SWCLK/TCK/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='82',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VCCPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='VCCPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='GNDPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='86',name='GNDPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='VDD25',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='~{TRST}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='C0+/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='C1-/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='C0-/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='99',name='PD6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4F110B2QR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4F110B2QR'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Stellaris Cortex M4 MCU NRND', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1231c3pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nLM4F110B2QR\n\nARM Stellaris Cortex M4 MCU NRND', 'pins':[
            Pin(num='1',name='SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/MNI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{HIB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='34',name='XOSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GNDX',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='XOSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4F110C4QR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4F110C4QR'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Stellaris Cortex M4 MCU NRND', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1231d5pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nLM4F110C4QR\n\nARM Stellaris Cortex M4 MCU NRND', 'pins':[
            Pin(num='1',name='SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/MNI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{HIB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='34',name='XOSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GNDX',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='XOSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4F110E5QR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4F110E5QR'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Stellaris Cortex M4 MCU NRND', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1231e6pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nLM4F110E5QR\n\nARM Stellaris Cortex M4 MCU NRND', 'pins':[
            Pin(num='1',name='SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/MNI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{HIB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='34',name='XOSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GNDX',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='XOSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4F110H5QR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4F110H5QR'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Stellaris Cortex M4 MCU NRND', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1231h6pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nLM4F110H5QR\n\nARM Stellaris Cortex M4 MCU NRND', 'pins':[
            Pin(num='1',name='SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/MNI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{HIB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='34',name='XOSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GNDX',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='XOSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4F111B2QR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4F111B2QR'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Stellaris Cortex M4 MCU NRND', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1230c3pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nLM4F111B2QR\n\nARM Stellaris Cortex M4 MCU NRND', 'pins':[
            Pin(num='1',name='I2C5SCL/SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/NMI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PG5/WT0CCP1/U2TX/I2C1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG4/WT0CCP0/U2RX/I2C1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG3/T5CCP1/I2C4SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG2/T5CCP0/I2C4SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1/T4CCP1/I2C3SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PG0/T4CCP0/I2C3SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='I2C5SDA/SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4F111C4QR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4F111C4QR'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Stellaris Cortex M4 MCU NRND', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1230d5pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nLM4F111C4QR\n\nARM Stellaris Cortex M4 MCU NRND', 'pins':[
            Pin(num='1',name='I2C5SCL/SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/NMI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PG5/WT0CCP1/U2TX/I2C1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG4/WT0CCP0/U2RX/I2C1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG3/T5CCP1/I2C4SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG2/T5CCP0/I2C4SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1/T4CCP1/I2C3SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PG0/T4CCP0/I2C3SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='I2C5SDA/SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4F111E5QR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4F111E5QR'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Stellaris Cortex M4 MCU NRND', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1230c3pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nLM4F111E5QR\n\nARM Stellaris Cortex M4 MCU NRND', 'pins':[
            Pin(num='1',name='I2C5SCL/SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/NMI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PG5/WT0CCP1/U2TX/I2C1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG4/WT0CCP0/U2RX/I2C1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG3/T5CCP1/I2C4SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG2/T5CCP0/I2C4SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1/T4CCP1/I2C3SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PG0/T4CCP0/I2C3SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='I2C5SDA/SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4F111H5QR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4F111H5QR'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Stellaris Cortex M4 MCU NRND', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1230h6pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nLM4F111H5QR\n\nARM Stellaris Cortex M4 MCU NRND', 'pins':[
            Pin(num='1',name='I2C5SCL/SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/NMI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PG5/WT0CCP1/U2TX/I2C1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG4/WT0CCP0/U2RX/I2C1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG3/T5CCP1/I2C4SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG2/T5CCP0/I2C4SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1/T4CCP1/I2C3SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PG0/T4CCP0/I2C3SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='I2C5SDA/SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TM4C1230D5PM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TM4C1230D5PM'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Tiva Cortex M4 MCU', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1230d5pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nTM4C1230D5PM\n\nARM Tiva Cortex M4 MCU', 'pins':[
            Pin(num='1',name='I2C5SCL/SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/NMI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PG5/WT0CCP1/U2TX/I2C1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG4/WT0CCP0/U2RX/I2C1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG3/T5CCP1/I2C4SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG2/T5CCP0/I2C4SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1/T4CCP1/I2C3SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PG0/T4CCP0/I2C3SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='I2C5SDA/SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TM4C1230E6PM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TM4C1230E6PM'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Tiva Cortex M4 MCU', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1230e6pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nTM4C1230E6PM\n\nARM Tiva Cortex M4 MCU', 'pins':[
            Pin(num='1',name='I2C5SCL/SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/NMI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PG5/WT0CCP1/U2TX/I2C1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG4/WT0CCP0/U2RX/I2C1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG3/T5CCP1/I2C4SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG2/T5CCP0/I2C4SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1/T4CCP1/I2C3SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PG0/T4CCP0/I2C3SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='I2C5SDA/SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TM4C1230H6PM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TM4C1230H6PM'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Tiva Cortex M4 MCU', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1230h6pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nTM4C1230H6PM\n\nARM Tiva Cortex M4 MCU', 'pins':[
            Pin(num='1',name='I2C5SCL/SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/NMI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PG5/WT0CCP1/U2TX/I2C1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG4/WT0CCP0/U2RX/I2C1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG3/T5CCP1/I2C4SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG2/T5CCP0/I2C4SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG1/T4CCP1/I2C3SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PG0/T4CCP0/I2C3SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='I2C5SDA/SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TM4C1231D5PM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TM4C1231D5PM'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Tiva Cortex M4 MCU', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1231d5pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nTM4C1231D5PM\n\nARM Tiva Cortex M4 MCU', 'pins':[
            Pin(num='1',name='SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/MNI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{HIB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='34',name='XOSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GNDX',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='XOSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TM4C1231E6PM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TM4C1231E6PM'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Tiva Cortex M4 MCU', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1231e6pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nTM4C1231E6PM\n\nARM Tiva Cortex M4 MCU', 'pins':[
            Pin(num='1',name='SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/MNI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{HIB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='34',name='XOSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GNDX',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='XOSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TM4C1231H6PM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TM4C1231H6PM'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM Tiva Cortex M4 MCU', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tm4c1231h6pm.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas.kicad_sym\nTM4C1231H6PM\n\nARM Tiva Cortex M4 MCU', 'pins':[
            Pin(num='1',name='SSI2RX/T0CCP0/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NMI/U2TX/WT5CCP1/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0-/U3TX/WT1CCP1/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='C0+/U3RX/WT1CCP0/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C1+/U1CTS/U1TX/U4TX/WT0CCP1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='C1-/U1RTS/U1RX/U4RX/WT0CCP0/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='U0RX/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='U0TX/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SSI0CLK/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SSI0FSS/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SSI0RX/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SSI0TX/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I2C1SCL/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I2C1SDA/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PF0/T0CCP0/SSI1RX/U1RTS/CAN0RX/C0O/MNI',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF1/T0CCP1/SSI1TX/U1CTS/C1O/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PF2/T1CCP0/SSI1CLK/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF3/T1CCP1/SSI1FSS/CAN0TX/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{HIB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='34',name='XOSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GNDX',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='XOSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SSI2TX/T0CCP1/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC0',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='U6RX/WT4CCP0/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='U6TX/WT4CCP1/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U1RX/T2CCP0/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='U1TX/T2CCP1/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='I2C0SCL/T3CCP0/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I2C0SDA/T3CCP1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TDO/SWO/T5CCP1/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF4/T2CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TDI/T5CCP0/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TMS/SWDIO/T4CCP1/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TCK/SWCLK/T4CCP0/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='U2RX/WT5CCP0/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDDC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='AIN11/CAN0TX/SSI2FSS/T1CCP1/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='AIN10/CAN0RX/SSI2CLK/T1CCP0/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE4/AIN9/U5RX/I2C2SCL/CAN0RX',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE3/AIN0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE5/AIN8/U5TX/I2C2SDA/CAN0TX',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='AIN7/I2C3SCL/SSI1CLK/SSI3CLK/WT2CCP0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AIN6/I2C3SDA/SSI1FSS/SSI3FSS/WT2CCP1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='AIN5/SSI1RX/SSI3RX/WT3CCP0/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='AIN4/SSI1TX/SSI3TX/WT3CCP1/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE2/AIN1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/AIN2/U7TX',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE0/AIN3/U7RX',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])